Attribute VB_Name = "basRadar"
' -------------------------------------------------------------------------
'
' basRadar(RadarC.BAS)                                Ulrich Mller 23.2.98
'                                                     Dell XPS P90    VB5.0
' Fischertechnik Radarturm : Public Variable
'      Public Routinen, Betriebsprogramme
'
' -------------------------------------------------------------------------

Option Explicit

' --- Interface Konstanten ------

Public Const cComNr = 1                   ' Nr des ComPorts
Public Const cReset = 8                   ' Reset-Eingang

' --- Farbcodierungen ---

Public Const cFarbeAus = &H8000000F
Public Const cFarbeAusH = &HE0E0E0
Public Const cFarbeEin = &HFF00&
Public Const cFarbeFehler = &HFF8&
Public Const cFarbeEnde = &H80C0FF

' --- Turm -------------------------

Public Const cRTurmMotor = 1              ' --- M1
Public Const cRTurmRechts = ftiRechts
Public Const cRTurmLinks = ftiLinks
Public Const cRTurmEnde = 2               ' --- E2
Public Const cRTurmImpuls = 1             ' --- E1

' --- Schirm ------------------------

Public Const cRSchirmMotor = 2            ' --- M2
Public Const cRSchirmAuf = ftiRechts
Public Const cRSchirmAb = ftiLinks
Public Const cRSchirmEnde = 4             ' --- E4
Public Const cRSchirmImpuls = 3           ' --- E3

' --- Handbetrieb ------------------

Public Const cRHandbetrieb = 4            ' --- M4
Public Const cRHandEin = ftiAus
Public Const cRHandAus = ftiEin

' --- RadarAuge --------------------

Public Const cRRadarAuge = ftiAEX
Public fKalib!                      ' Kalibrierungsfaktor

' --- Public Variable --------------

Public ft As clsFishFace
Public mf As frmRadarMain           ' Kurzschreibweise fr RadarMain
Public ProgrammNr%                  ' Nr des akt. laufenden Programms
Public ProgrammBeenden As Boolean   ' Anforderung Programmende

' --- Modul globale Variable -------

Private TurmPosition%               ' Turmposition in Anzahl Impulsen
                                    ' Position Rechts = 0
Private SchirmPosition%             ' Schirmposition in Anzahl Impulsen
                                    ' Position Oben = 0
Private Turm350%                    ' Anzahl Impulse fr eine 350 Drehung
Private TurmIncr%                   ' Anzahl Impulse fr ein Increment
Private Schirm45%                   ' Anzahl Impulse fr eine 45 Senkung
Private SchirmRichtung%             ' Bewegungsrichtung des Schirms



Private Sub Grundstellung()

' --- Fahren des Radarturmes in Grundstellung ---
'     Turm : rechts, Endschalter, Schirmauf
  
  If Not ft.GetInput(cRTurmEnde) Then ft.SetMotor cRTurmMotor, cRTurmRechts
  If Not ft.GetInput(cRSchirmEnde) Then ft.SetMotor cRSchirmMotor, cRSchirmAuf
  
  Do
    If ft.GetInput(cRTurmEnde) Then ft.SetMotor cRTurmMotor, ftiAus
    If ft.GetInput(cRSchirmEnde) Then ft.SetMotor cRSchirmMotor, ftiAus
  Loop Until ft.GetInput(cRTurmEnde) And ft.GetInput(cRSchirmEnde)
  
  ft.SetMotor cRTurmMotor, ftiAus
  ft.SetMotor cRSchirmMotor, ftiAus
  TurmPosition = 0
  SchirmPosition = 0
  
End Sub

Public Sub RadarAnzeige(ImpulsNr%, Schritte%)

' --- Anzeige des aktuellen Helligkeitswertes auf picRadar ---
'     und der Positionsmarken auf picRadarX/Y

Dim Anzeige As Boolean

  If (ImpulsNr Mod Schritte) = 0 Then Anzeige = True Else Anzeige = False
  
  If SchirmRichtung = cRSchirmAb Then
    If Anzeige Then mf!picRadarY.Line (2, SchirmPosition - Schritte + 1)-Step(6, 1), cFarbeAusH, BF
    SchirmPosition = SchirmPosition + 1
    If Anzeige Then
      RadarWert
      mf!picRadarY.Line (2, SchirmPosition)-Step(6, 1), cFarbeEin, BF
    End If
  Else
    If Anzeige Then mf!picRadarY.Line (2, SchirmPosition + Schritte - 1)-Step(6, 1), cFarbeAusH, BF
    SchirmPosition = SchirmPosition - 1
    If Anzeige Then
      RadarWert
      mf!picRadarY.Line (2, SchirmPosition)-Step(6, 1), cFarbeEin, BF
    End If
  End If

End Sub


Private Sub RadarWert()

' --- Anzeige des aktuellen Wertes von cRRadarAuge auf picRadar ---

Static Helligkeit!

  Helligkeit = ft.GetAnalog(cRRadarAuge)
  If Helligkeit = 0 Then Helligkeit = 1024
  Helligkeit = 1025 - Helligkeit            ' --- Heller : grerer Wert
  Helligkeit = Helligkeit * fKalib + 79     ' --- Grundhelligkeit : 79
                                            ' --- Scalieren auf Restbereich
  mf!picRadar.Line (TurmPosition, SchirmPosition)-Step(10, 1), RGB(0, Helligkeit, 0), BF
  
End Sub


Private Sub ScanAbwrts()

' --- Scannen der Lichtwerte bei Schirm Abwrts ---

Dim i%

  ft.SetMotor cRSchirmMotor, cRSchirmAb
  SchirmRichtung = cRSchirmAb
  
  RadarWert
  
  ft.WaitForChange cRSchirmImpuls, Schirm45
  
  ft.SetMotor cRSchirmMotor, ftiAus
  
End Sub


Private Sub ScanAufwrts()

' --- Scannen der Lichtwerte bei Schirm Aufwrts ---

  ft.SetMotor cRSchirmMotor, cRSchirmAuf
  SchirmRichtung = cRSchirmAuf
  
  
    ft.WaitForChange cRSchirmImpuls, Schirm45, cRSchirmEnde
  
  ft.SetMotor cRSchirmMotor, ftiAus
  SchirmPosition = 0
  
  RadarWert
  
End Sub


Public Sub StandardScan()

' --- Scan der Helligkeitswerte der Umgebung und Anzeige in picRadar ---
'     Schleife, Ende durch

  mf!lblStatus = "StandardScan : auf Grundstellung"

' --- Scanwerte ---

  Turm350 = 330
  TurmIncr = 15
  Schirm45 = 44
  
' --- Beschriftung Form, Init pic-Bereiche ---

  mf!lblRadarX = Turm350
  mf!lblRadarY = Schirm45
  mf!picRadar.Scale (0, 0)-(Turm350 + 15, Schirm45)
  mf!picRadar.Cls
  mf!picRadarX.Scale (0, 0)-(Turm350 + 15, 10)
  mf!picRadarX.Cls
  mf!picRadarY.Scale (0, 0)-(10, Schirm45)
  mf!picRadarY.Cls
  
' --- Anfahren der Grundstellung ---

  Grundstellung
    
' --- Scan-Schleife, Abbruch durch Button cmdAction ---

  mf!lblStatus = "StandardScan luft"
  
  Do
    ScanAbwrts
    TurmIncrement
    ScanAufwrts
    TurmIncrement
  Loop Until ProgrammBeenden
  
  ft.ClearMotors
  mf!lblStatus = "StandardScan beendet"
  mf!lblStatus.BackColor = cFarbeEnde
  
End Sub

Private Sub TurmIncrement()

' --- Drehen des Turms um TurmIncr, die Drehrichtung wird selbstndig
'     bestimmt, vor dem ersten Aufruf Position am rechten Endschalter

Static DrehRichtung%, PosAdd%

' --- Richtungsbestimmung ---

  If ft.GetInput(cRTurmEnde) Then
    ft.SetMotor cRTurmMotor, cRTurmLinks
    ft.WaitForLow cRTurmImpuls            ' um den Endschalter zu lsen
    TurmPosition = 0
    DrehRichtung = cRTurmLinks
    PosAdd = TurmIncr
    mf!picRadarX.Line (TurmPosition, 2)-Step(10, 6), cFarbeEin, BF
  End If
  If TurmPosition >= Turm350 Then
    DrehRichtung = cRTurmRechts
    PosAdd = -TurmIncr
  End If
  
' --- Drehen um das Increment (TurmIncr) --------

  ft.SetMotor cRTurmMotor, DrehRichtung
  ft.WaitForChange cRTurmImpuls, TurmIncr, cRTurmEnde
  ft.SetMotor cRTurmMotor, ftiAus
  mf!picRadarX.Line (TurmPosition, 2)-Step(10, 6), cFarbeAusH, BF
  TurmPosition = TurmPosition + PosAdd
  mf!picRadarX.Line (TurmPosition, 2)-Step(10, 6), cFarbeEin, BF
  
End Sub


